@@ -30,9 +30,19 @@ API_ERROR_SYSTEM_ID_OUT_RANGE = "systemid out of range"
 API_ERROR_ZONE_ID_NOT_AVAILABLE = "zoneid not avaiable"
 API_ERROR_ZONE_ID_OUT_RANGE = "zoneid out of range"
 
+API_SYSTEM_PARAMS = [API_MODE]
+API_ZONE_PARAMS = [
+    API_COLD_STAGE,
+    API_HEAT_STAGE,
+    API_NAME,
+    API_ON,
+    API_SET_POINT,
+]
+
 AZD_AIR_DEMAND = "air_demand"
 AZD_COLD_STAGE = "cold_stage"
 AZD_COLD_STAGES = "cold_stages"
+AZD_DEMAND = "demand"
 AZD_ERRORS = "errors"
 AZD_FLOOR_DEMAND = "floor_demand"
 AZD_HEAT_STAGE = "heat_stage"
@@ -43,6 +53,7 @@ AZD_MODE = "mode"
 AZD_MODES = "modes"
 AZD_NAME = "name"
 AZD_ON = "on"
+AZD_PROBLEMS = "problems"
 AZD_SYSTEM = "system"
 AZD_SYSTEMS = "systems"
 AZD_SYSTEMS_NUM = "num_systems"
